<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Vybrať písmo terminálu</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Písmo:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Veľkosť:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Náhľad</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="91"/>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="193"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Terminál zobrazíte stlačením „%1“.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Následujúca karta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Predošlá karta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Move Tab &amp;Left</source>
        <translation>&amp;Presunúť kartu doľava</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="257"/>
        <source>Move Tab &amp;Right</source>
        <translation>&amp;Presunúť kartu doprava</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>&amp;Rozdeliť terminál vodorovne</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="279"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>&amp;Rozdeliť terminál zvisle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>Zbaliť dielčí terminál</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Vyčistiť aktívny terminál</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="174"/>
        <source>Keep window open when it loses focus</source>
        <translation>Nechať okno otvorené, ak stratí zameranie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Predchodí panel v chronológii</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;Následujúci panel v histórii</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Tab</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>Go to</source>
        <translation>Prejsť na</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Horný dielčí terminál</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;Dolný dielčí terminál</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>L&amp;eft Subterminal</source>
        <translation>&amp;Ľavý dielčí terminál</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>R&amp;ight Subterminal</source>
        <translation>&amp;Pravý dielčí terminál</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Copy &amp;Selection</source>
        <translation>&amp;Skopírovať výber</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Paste Clip&amp;board</source>
        <translation>&amp;Vložiť obsah schránky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Paste S&amp;election</source>
        <translation>&amp;Vložiť výber</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Zoom &amp;in</source>
        <translation>&amp;Priblížiť</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Zoom &amp;out</source>
        <translation>&amp;Oddialiť</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Zoom rese&amp;t</source>
        <translation>&amp;Vrátiť na pôvodnú veľkosť</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>&amp;Find...</source>
        <translation>&amp;Nájsť...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Handle history...</source>
        <translation>Zaobchádzanie s históriou...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>&amp;Save Session</source>
        <translation>&amp;Uložiť reláciu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="340"/>
        <source>&amp;Load Session</source>
        <translation>&amp;Načítať reláciu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Zobraziť/skryť ponuku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="352"/>
        <source>Rename session</source>
        <translation>Premenovať reláciu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Nová karta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Nová karta &amp; Prednastavenie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="366"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;Terminál</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="368"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 vodorovné &amp;terminály</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 &amp;Zvislé terminály</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>4 Terminal&amp;s</source>
        <translation>&amp;Terminály</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zatvoriť kartu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nové okno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="386"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Predvoľby...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončiť</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Skryť okraje okien</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;Zobraziť panel s kartami</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="422"/>
        <source>Fullscreen</source>
        <translation>Na celú obrazovku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Toggle Bookmarks</source>
        <translation>Zobraziť/skryť položky</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Dole</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>&amp;Top</source>
        <translation>&amp;Hore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Right</source>
        <translation>&amp;Vpravo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="475"/>
        <source>&amp;Left</source>
        <translation>&amp;Vľavo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="457"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;Rozvrhnutie kariet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>&amp;None</source>
        <translation>&amp;Žiadne</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="491"/>
        <source>S&amp;crollbar Layout</source>
        <translation>&amp;Zobrazenie posuvníku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Blokový ukazovateľ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>&amp;UnderlineCursor</source>
        <translation>&amp;Podtržníkový ukazovateľ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;Ukazovateľ v podobe zvisle</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Tvar kurzoru</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Exit QTerminal</source>
        <translation>Ukončiť QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Do not ask again</source>
        <translation>Nepýtať sa znovu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="637"/>
        <source>Are you sure you want to exit?</source>
        <translation>Určite chcete program ukončiť?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="662"/>
        <source>About</source>
        <translation>O programe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="664"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>Rýchly a výkonný multiplatformový emulátor terminálu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="666"/>
        <source>Copyright (C) </source>
        <translation>Copyright (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="666"/>
        <source>2013-2022</source>
        <translation>2013-2022</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="668"/>
        <source>LXQt Project</source>
        <translation>Projekt LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="670"/>
        <source>Development: </source>
        <translation>Vývoj: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Nastavenie terminálu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>Vzhľad</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>Behavior</source>
        <translation>Správanie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <source>Shortcuts</source>
        <translation>Klávesové skratky</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="48"/>
        <source>Dropdown</source>
        <translation>Rozbaľovacia ponuka</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="57"/>
        <source>Bookmarks</source>
        <translation>Záložky</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="272"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Iba pri jednej karte skryť panel kariet</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="173"/>
        <source>Color scheme</source>
        <translation>Farebná schéma</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="199"/>
        <source>Scrollbar position</source>
        <translation>Pozícia posuvníka</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="463"/>
        <source>Start with preset:</source>
        <translation>Spustiť s prednastavením:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Show a border around the current terminal</source>
        <translation>Zobraziť okraj okolo práve používaného terminálu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="380"/>
        <source>Terminal transparency</source>
        <translation>Prehľadnosť terminálu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="354"/>
        <source>Application transparency</source>
        <translation>Prehľadnosť aplikácie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="474"/>
        <source>None (single terminal)</source>
        <translation>Žiadne (jediný terminál)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>2 terminals horizontally</source>
        <translation>2 terminály vodorovne</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="484"/>
        <source>2 terminals vertically</source>
        <translation>2 terminály zvisle</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>4 terminals</source>
        <translation>4 terminály</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="364"/>
        <location filename="../forms/propertiesdialog.ui" line="390"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="127"/>
        <source>Font</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="163"/>
        <source>&amp;Change...</source>
        <translation>&amp;Zmeniť…</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="212"/>
        <source>Tabs position</source>
        <translation>Pozícia kariet</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="186"/>
        <source>Widget style</source>
        <translation>Štýl ovládacieho prvku</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Show the menu bar</source>
        <translation>Zobraziť panel ponúk</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>Cursor shape</source>
        <translation>Tvar kurzoru</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="316"/>
        <source>Change window title based on current terminal</source>
        <translation>Zmeniť nadpis okna podľa práve aktívneho terminálu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="323"/>
        <source>Change window icon based on current terminal</source>
        <translation>Zmeniť ikonu okna podľa práve aktívneho terminálu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="337"/>
        <source>Enable bi-directional text support</source>
        <translation>Zabudnúť obojsmernú podporu textu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="406"/>
        <source>Background image:</source>
        <translation>Obrázok na pozadí:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Select</source>
        <translation>Vybrať</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="330"/>
        <source>Show terminal size on resize</source>
        <translation>Pri zmene veľkosti terminálu zobraziť jeho rozmery</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="279"/>
        <source>Fixed tab width:</source>
        <translation>Fixná veľkosť panelu:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="289"/>
        <location filename="../forms/propertiesdialog.ui" line="507"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="306"/>
        <source>Show close button on each tab</source>
        <translation>Zobraziť tlačítko pre zatváranie na každej karte</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="497"/>
        <source>Terminal margin</source>
        <translation>Okraj terminálu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Použiť znak obdĺžnika, ktorý je obsiahnutý v písme</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Urýchľovače sa zobrazia po stlačení klávesnice Alt a môžu kolidovať s terminálom.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="251"/>
        <source>No menu bar accelerator</source>
        <translation>Žiadny urýchľovač v lište ponuky</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="830"/>
        <source>Emulation</source>
        <translation>Emulácia</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="614"/>
        <source>Action after paste</source>
        <translation>Akcia pre vloženie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="654"/>
        <source>Confirm multiline paste</source>
        <translation>Vyžadovať potvrdenie pri vkladaní viacriadkového textu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="661"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Z vkladaného textu odobrať konce riadkov</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="757"/>
        <source>Open new terminals in current working directory</source>
        <translation>Otvárať nové terminály na aktuálnej pracovnej zložke</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="692"/>
        <source>Save Size when closing</source>
        <translation>Pri zatváraní uložiť veľkosť</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="685"/>
        <source>Save Position when closing</source>
        <translation>Pri zatváraní uložiť pozíciu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="678"/>
        <source>Ask for confirmation when closing</source>
        <translation>Pri zatváraní vyžadovať potvrdenie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="594"/>
        <source>Unlimited history</source>
        <translation>Neobmedzená história</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="587"/>
        <source>History size (in lines)</source>
        <translation>Hĺbka histórie (v riadkoch)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="781"/>
        <source>Default $TERM</source>
        <translation>Východzie $TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="704"/>
        <source>Start with this size:</source>
        <translation>Spustiť s touto veľkosťou:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Background mode:</source>
        <translation>Režim na pozadí:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>None</source>
        <translation>Meno</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="440"/>
        <source>Stretch</source>
        <translation>Roztiahnuť</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="450"/>
        <source>Fit</source>
        <translation>Prispôsobiť</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="455"/>
        <source>Center</source>
        <translation>Stred</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="344"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Určte, či majú byť znaky vykresľujúce rámček vykreslené programom QTerminal, alebo ponechané na podkladových knižniciach vykreslenia písma.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Prepnúť na použitie tučného písma na vykreslenie intenzívnych farieb</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="241"/>
        <source>Use bold font face for intense colors</source>
        <translation>Použiť tučné písmo na zvýraznenie farby</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>&amp;Hide Window Borders</source>
        <translation>Skryť okraje okien</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="839"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;QTerminal napodobní vybraný systém. Vaša voľba nemusí byť totožná s vašim operačným systémom.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="817"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Tento príkaz bude spustený a ako argument sa použije názov dočasného súboru, ktorý obsahuje históriu posúvania</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="820"/>
        <source>Handle history command</source>
        <translation>Spracovanie príkazu histórie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="711"/>
        <location filename="../forms/propertiesdialog.ui" line="725"/>
        <source> px</source>
        <translation> pixely</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="732"/>
        <source>Get current size</source>
        <translation>Ísť na súčasnú veľkosť</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="767"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Otvorte novú kartu napravo od aktívnej karty</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="764"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Ak nie je vybraté, nová karta sa otvorí, ako karta, úplne vpravo</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="668"/>
        <source>Close tab on middle-click</source>
        <translation>Po kliknutí stredným tlačidlom zatvoríte kartu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="647"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Vynútené deaktivovanie režimu vkladania zátvoriek</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="627"/>
        <source>Word selection characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="634"/>
        <source>When selecting text by word, consider these characters as part of words in addition to alphanumeric characters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>:@-./_~</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="644"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>Režim vkladania v zátvorkách je užitočný na prilepenie viacriadkových reťazcov.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="774"/>
        <source>Audible bell</source>
        <translation>Počuteľný zvonček</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="863"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Úprava odkazu:
1. Dvakrát kliknúť na jeho kľúč
2. Stlačiť požadovanú kombináciu kláves
3. Kliknúť na odkaz alebo stlačiť Enter

Ak chcete odstrániť alebo zakázať odkaz, v bode 2 stlačte iba modifikátor (napríklad Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="893"/>
        <source>Shortcut</source>
        <translation>Klávesová skratka</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="898"/>
        <source>Key</source>
        <translation>Klávesa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="910"/>
        <source>Show on start</source>
        <translation>Zobraziť pri spustení</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="917"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>Na vodorovnom paneli kariet je zobrazené tlačítko uzamknutia</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="920"/>
        <source>Keep window open when it loses focus</source>
        <translation>Nechať okno otvorené, ak stratí zameranie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="927"/>
        <source>Size</source>
        <translation>Veľkosť</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="938"/>
        <source>Height</source>
        <translation>Výška</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="948"/>
        <location filename="../forms/propertiesdialog.ui" line="965"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="955"/>
        <source>Width</source>
        <translation>Šírka</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="979"/>
        <source>Shortcut:</source>
        <translation>Klávesová skratka:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1046"/>
        <source>Edit bookmark file contents</source>
        <translation>Upraviť obsah súboru záložiek</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1005"/>
        <source>Enable bookmarks</source>
        <translation>Používať záložky</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1014"/>
        <source>Bookmark file</source>
        <translation>Súbor so záložkami</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1027"/>
        <source>Find...</source>
        <translation>Hľadať...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1036"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Môžete stanoviť svoje vlastné umiestnenie súboru so záložkami. To umožňuje jednoduché zdieľanie záložiek pomocou nástrojov ako je OwnCloud alebo Dropbox.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <source>No scrollbar</source>
        <translation>Žiadny posuvník</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Left</source>
        <translation>Vľavo</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Top</source>
        <translation>Hore</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>BlockCursor</source>
        <translation>Blokový kurzor</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>UnderlineCursor</source>
        <translation>Podtržníkový kurzor</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>IBeamCursor</source>
        <translation>Ukazovateľ v podobe zvisle</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>No move</source>
        <translation>Bez posunu</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to top</source>
        <translation>Posun smerom hore</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to bottom</source>
        <translation>Posun smerom dole</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="271"/>
        <source>Examples</source>
        <translation>Príklady</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="422"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Obrázky (* .bmp * .jpg * .png * .svg * .xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="512"/>
        <source>Open bookmarks file</source>
        <translation>Otvoriť súbor so záložkami</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="514"/>
        <source>XML files (*.xml)</source>
        <translation>Súbory XML (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="515"/>
        <source>All files (*)</source>
        <translation>Všetky súbory (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="614"/>
        <location filename="../propertiesdialog.cpp" line="618"/>
        <source>Question</source>
        <translation>Otázka</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="614"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>Chcete prepísať tento súbor so záložkami?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="618"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>Názov súboru so záložkami nekončí na &apos;.xml&apos;.
Ste si istý, že ho chcete prepísať?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="626"/>
        <source>Warning</source>
        <translation>Varovanie</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="626"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>Do tohto súboru nie je možné zapisovať záložky:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="206"/>
        <location filename="../propertiesdialog.cpp" line="317"/>
        <source>System Default</source>
        <translation>Východzie nastavenie systému</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="421"/>
        <source>Choose a background image</source>
        <translation>Zvoliť obrázok na pozadí</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>Synchronizované záložky</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="81"/>
        <location filename="../tabwidget.cpp" line="235"/>
        <source>Shell No. %1</source>
        <translation>Shell číslo %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="203"/>
        <source>Tab name</source>
        <translation>Názov karty</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="204"/>
        <source>New tab name:</source>
        <translation>Nový názov karty:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="224"/>
        <source>Select new tab title color</source>
        <translation>Zvoliť farbu názvu novej karty</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="253"/>
        <source>Close session</source>
        <translation>Zatvoriť reláciu</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="255"/>
        <source>Change title color</source>
        <translation>Zmeniť farbu titulku</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="77"/>
        <source>Load Session</source>
        <translation>Načítať reláciu</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="78"/>
        <source>List of saved sessions:</source>
        <translation>Zoznam uložených sedení:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Hlavné okno</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Súbor</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Akcia</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Zobrazenie</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Úpravy</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;O aplikácii...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Informácie o Qt...</translation>
    </message>
</context>
</TS>
